import { type ReactiveControllerHost } from 'lit';
import { type DisconnectCallback } from './events';
export declare type DiscovererHost = ReactiveControllerHost & HTMLElement;
export declare type DiscoveryCallback = (element: HTMLElement, onDisconnect: DisconnectCallback) => void;
export declare type Discoverer = {
    host: DiscovererHost;
    callback: DiscoveryCallback;
};
export declare type Discoverable = {
    element: HTMLElement;
    onDisconnect: DisconnectCallback;
};
export declare function discover(host: DiscovererHost, id: symbol, callback: DiscoveryCallback): void;
/**
 * Fires the given `eventType` when the given `host` connects to the DOM. A discovery event
 * also contains an event detail of the form `{ element: host; onDisconnect: () => void; }`.
 *
 * The discoverable element can be registered so other elements can be guaranteed to discover
 * it using the `discover()` function. Events can be missed depending on the define import order
 * because slotted custom elements may be defined before their parent.
 */
export declare function discoverable(host: DiscovererHost, eventType: keyof GlobalEventHandlersEventMap, options?: {
    register?: symbol;
}): void;
//# sourceMappingURL=discover.d.ts.map