import { type Context } from '../context';
import { type StoreSubscriptionHost } from './storeSubscription';
import type { ReadableStoreRecord, StoreValue, WritableStoreRecord } from './types';
/**
 * Helper function to subscribe to an individual store record item for the life of the given
 * `host` element.
 *
 * @example
 * ```ts
 * import { LitElement } from 'lit';
 * import { storeRecordSubscription, mediaStoreContext } from '@vidstack/player';
 *
 * class MyElement extends LitElement {
 *   constructor() {
 *     super();
 *     storeRecordSubscription(this, mediaStoreContext, 'paused', ($value) => {
 *       // ...
 *     });
 *   }
 * }
 * ```
 */
export declare function storeRecordSubscription<StoreRecord extends ReadableStoreRecord, Key extends keyof StoreRecord>(host: StoreSubscriptionHost, store: StoreRecord | Context<StoreRecord>, key: Key, onChange: (value: StoreValue<StoreRecord[Key]>) => void): void;
/**
 * Copies matching store record values from `storeRecordA` to `storeRecordB`.
 */
export declare function copyStoreRecords(storeRecordA: WritableStoreRecord, storeRecordB: WritableStoreRecord): void;
/**
 * Unwraps a store record using a proxy and returning the underlying value when a key is accessed.
 */
export declare function unwrapStoreRecord<StoreRecord extends ReadableStoreRecord>(store: StoreRecord): {
    [Prop in keyof StoreRecord]: StoreValue<StoreRecord[Prop]>;
};
//# sourceMappingURL=storeRecord.d.ts.map